@@ -2,7 +2,11 @@
 # only run tests that do not require network access for downloading files
 cd test
 
+function clear(varargin)
+endfunction
+
 # No for-loop, as the test files call clean()
+
 file = 'test_mex_accuracy.m';
 disp(['Testing ', file]);
 source(file);
